@@ -1,4 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+ * vi:set noexpandtab tabstop=8 shiftwidth=8:
  *
  * Copyright (C) 2019 Richard Hughes <richard@hughsie.com>
  *
@@ -35,6 +36,8 @@ gs_plugins_fedora_langpacks_func (GsPluginLoader *plugin_loader)
 					 "refine-flags", GS_PLUGIN_REFINE_FLAGS_REQUIRE_ICON,
 					 NULL);
 	list = gs_plugin_loader_job_process (plugin_loader, plugin_job, NULL, &error);
+	g_assert_nonnull (list);
+	g_assert_no_error (error);
 
 	/* check if we have just one app in the list */
 	g_assert_cmpint (gs_app_list_length (list), ==, 1);
@@ -51,12 +54,16 @@ main (int argc, char **argv)
 	gboolean ret;
 	g_autoptr(GError) error = NULL;
 	g_autoptr(GsPluginLoader) plugin_loader = NULL;
-	const gchar *whitelist[] = {
+	const gchar *allowlist[] = {
 		"fedora-langpacks",
 		NULL
 	};
 
-	g_test_init (&argc, &argv, NULL);
+	g_test_init (&argc, &argv,
+#if GLIB_CHECK_VERSION(2, 60, 0)
+		     G_TEST_OPTION_ISOLATE_DIRS,
+#endif
+		     NULL);
 	g_setenv ("G_MESSAGES_DEBUG", "all", TRUE);
 
 	/* only critical and error are fatal */
@@ -66,7 +73,7 @@ main (int argc, char **argv)
 	plugin_loader = gs_plugin_loader_new ();
 	gs_plugin_loader_add_location (plugin_loader, LOCALPLUGINDIR);
 	ret = gs_plugin_loader_setup (plugin_loader,
-				      (gchar**) whitelist,
+				      (gchar**) allowlist,
 				      NULL,
 				      NULL,
 				      &error);
