@@ -1,4 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+ * vi:set noexpandtab tabstop=8 shiftwidth=8:
  *
  * Copyright (C) 2015-2016 Richard Hughes <richard@hughsie.com>
  *
@@ -12,6 +13,7 @@
 #include <string.h>
 #include "gs-content-rating.h"
 
+#if !AS_CHECK_VERSION(0, 7, 18)
 static const gchar *rating_system_names[] = {
 	[GS_CONTENT_RATING_SYSTEM_UNKNOWN] = NULL,
 	[GS_CONTENT_RATING_SYSTEM_INCAA] = "INCAA",
@@ -382,7 +384,9 @@ gs_content_rating_key_value_to_str (const gchar *id, AsContentRatingValue value)
 
 	return NULL;
 }
+#endif  /* appstream-glib < 0.7.18 */
 
+#if !AS_CHECK_VERSION(0, 7, 15)
 /* Equivalent to as_content_rating_get_all_rating_ids() */
 const gchar **
 gs_content_rating_get_all_rating_ids (void)
@@ -395,7 +399,9 @@ gs_content_rating_get_all_rating_ids (void)
 
 	return (const gchar **) g_ptr_array_free (g_steal_pointer (&ids), FALSE);
 }
+#endif  /* appstream-glib < 0.7.15 */
 
+#if !AS_CHECK_VERSION(0, 7, 18)
 static char *
 get_esrb_string (gchar *source, gchar *translate)
 {
@@ -775,3 +781,4 @@ gs_utils_content_rating_system_from_locale (const gchar *locale)
 	/* everything else is IARC */
 	return GS_CONTENT_RATING_SYSTEM_IARC;
 }
+#endif  /* appstream-glib < 0.7.18 */
